//
// Maze carving program.
// 
// Does a depth-first search of possible paths.
// See: http://en.wikipedia.org/wiki/Maze_generation_algorithm
// 
// Text-based (so, suitable for Dragonfly).
//

// Engine includes
#include "Config.h"
#include "GameManager.h"
#include "LogManager.h"

// Game includes
#include "maze.h"
#include "Cell.h"
#include "Carver.h"
#include "WallHorizontal.h"
#include "WallVertical.h"

int main(int argc, char *argv[]) { 
  int frame_time;

  // See if command line args.
  if (argc > 2) {
    fprintf(stderr, "Maze carver, version %.1f\n", VERSION);
    fprintf(stderr, "Usage: %s [num]\n", argv[0]);
    fprintf(stderr, "\twhere num is in milliseconds between moves\n");
    fprintf(stderr, "\t(default 33).\n");
    return 1;
  }
  if (argc==2)
    frame_time = atoi(argv[1]);
  else
    frame_time = -1;

  // Start up Game Manager
  df::GameManager &game_manager = df::GameManager::getInstance();
  if (game_manager.startUp())  {
    df::LogManager &log_manager = df::LogManager::getInstance();
    log_manager.writeLog("Error starting game manager!");
    game_manager.shutDown();
    exit(1);
  }

  // Set frame time if command line arg.
  if (frame_time != -1)
    df::Config::getInstance().setFrameTime(frame_time);

  // Carver creates maze.
  new Carver;

  // Run the game (this blocks until the game loop is over)
  game_manager.run();

  // Shut everything down
  game_manager.shutDown();
}
